#ifndef IWRAP_HEADER
#define IWRAP_HEADER

#include "uccl.h"

extern int instruction_wrapper_invalid(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_go(class cl_uc *uc, t_mem code);

extern int instruction_wrapper_00(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_00(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_01(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_01(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_02(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_02(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_03(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_03(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_04(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_04(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_05(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_05(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_06(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_06(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_07(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_07(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_08(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_08(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_09(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_09(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_0f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_10(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_10(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_11(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_11(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_12(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_12(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_13(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_13(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_14(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_14(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_15(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_15(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_16(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_16(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_17(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_17(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_18(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_18(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_19(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_19(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_1f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_20(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_20(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_21(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_21(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_22(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_22(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_23(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_23(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_24(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_24(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_25(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_25(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_26(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_26(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_27(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_27(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_28(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_28(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_29(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_29(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_2f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_30(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_30(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_31(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_31(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_32(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_32(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_33(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_33(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_34(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_34(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_35(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_35(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_36(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_36(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_37(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_37(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_38(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_38(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_39(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_39(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_3f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_40(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_40(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_41(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_41(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_42(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_42(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_43(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_43(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_44(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_44(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_45(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_45(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_46(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_46(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_47(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_47(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_48(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_48(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_49(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_49(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_4f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_50(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_50(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_51(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_51(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_52(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_52(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_53(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_53(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_54(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_54(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_55(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_55(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_56(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_56(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_57(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_57(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_58(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_58(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_59(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_59(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_5f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_60(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_60(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_61(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_61(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_62(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_62(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_63(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_63(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_64(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_64(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_65(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_65(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_66(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_66(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_67(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_67(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_68(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_68(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_69(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_69(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_6f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_70(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_70(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_71(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_71(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_72(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_72(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_73(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_73(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_74(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_74(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_75(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_75(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_76(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_76(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_77(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_77(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_78(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_78(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_79(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_79(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_7f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_80(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_80(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_81(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_81(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_82(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_82(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_83(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_83(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_84(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_84(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_85(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_85(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_86(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_86(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_87(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_87(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_88(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_88(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_89(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_89(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_8f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_90(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_90(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_91(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_91(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_92(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_92(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_93(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_93(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_94(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_94(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_95(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_95(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_96(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_96(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_97(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_97(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_98(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_98(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_99(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_99(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9a(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9b(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9c(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9d(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9e(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_9f(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_a9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_aa(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_aa(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ab(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ab(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ac(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ac(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ad(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ad(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ae(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ae(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_af(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_af(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_b9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ba(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ba(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_be(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_be(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bf(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_bf(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_c9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ca(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ca(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ce(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ce(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cf(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_cf(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_d9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_da(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_da(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_db(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_db(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_dc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_dc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_dd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_dd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_de(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_de(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_df(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_df(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_e9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ea(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ea(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_eb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_eb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ec(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ec(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ed(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ed(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ee(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ee(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ef(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ef(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f0(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f1(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f2(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f3(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f4(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f5(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f6(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f7(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f8(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_f9(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fa(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fa(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fb(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fc(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fd(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fe(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_fe(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ff(class cl_uc *uc, t_mem code);
extern int instruction_wrapper_ff(class cl_uc *uc, t_mem code);

extern void fill_def_wrappers(instruction_wrapper_fn itab[]);


#endif

/* End of sim.src/iwrap.h */
